Skip to contents

Opens an interactive Shiny interface for uploading a CSV file, inspecting dataset diagnostics, visualizing a selected variable, and downloading a reproducible DataSum report source file.

Usage

run_datasum_app(data = NULL)

Arguments

data

Optional data frame used as the starting dataset. If omitted, the app starts with datasets::iris until a CSV is uploaded.

Value

A Shiny application object.

Examples

if (requireNamespace("shiny", quietly = TRUE)) {
  app <- run_datasum_app(iris)
}